==> pluxml_5.3.orig.tar.gz: PluXml-5.3/core/lang/ru/core.php <==
<?php

$LANG = array(

'L_LANGUE'						=> 'Russian',

# common
'L_PLUXML_VERSION'				=> 'PluXml версия',
'L_HOMEPAGE'					=> 'Главная',
'L_UNCLASSIFIED'				=> 'Без категории',
'L_INFO_PHP_VERSION'			=> 'PHP версия',
'L_INFO_MAGIC_QUOTES'			=> 'Состояние "magic quotes"',
'L_INFO_CHARSET'				=> 'кодировка',

# index.php
'L_ERR_THEME_NOTFOUND'			=> 'Тема не найдена',
'L_ERR_FILE_NOTFOUND'			=> 'Файл не найден',
'L_ERR_PAGE_NOT_FOUND'			=> 'Страница не найдена',

# class.plx.date.php
'L_SHORT_JANUARY'				=> '',
'L_SHORT_FEBRUARY'				=> '',
'L_SHORT_MARCH'					=> '',
'L_SHORT_APRIL'					=> '',
'L_SHORT_MAY'					=> '',
'L_SHORT_JUNE'					=> '',
'L_SHORT_JULY'					=> '',
'L_SHORT_AUGUST'				=> '',
'L_SHORT_SEPTEMBER'				=> '',
'L_SHORT_OCTOBER'				=> '',
'L_SHORT_NOVEMBER'				=> '',
'L_SHORT_DECEMBER'				=> '',
'L_JANUARY'						=> 'январь',
'L_FEBRUARY'					=> 'февраль',
'L_MARCH'						=> 'март',
'L_APRIL'						=> 'апрель',
'L_MAY'							=> 'май',
'L_JUNE'						=> 'июнь',
'L_JULY'						=> 'июль',
'L_AUGUST'						=> 'август',
'L_SEPTEMBER'					=> 'сентябрь',
'L_OCTOBER'						=> 'октябрь',
'L_NOVEMBER'					=> 'ноябрь',
'L_DECEMBER'					=> 'декабрь',
'L_MONDAY'						=> 'понедельник',
'L_TUESDAY'						=> 'вторник',
'L_WEDNESDAY'					=> 'среда',
'L_THURSDAY'					=> 'четверг',
'L_FRIDAY'						=> 'пятница',
'L_SATURDAY'					=> 'субота',
'L_SUNDAY'						=> 'воскресенье',

# class.plx.capcha.php
'L_LAST'						=> 'последняя',
'L_FIRST'						=> 'первая',
'L_SECOND'						=> 'вторая',
'L_THIRD'						=> 'третья',
'L_FOURTH'						=> 'четвертая',
'L_FIFTH'						=> 'пятая',
'L_SIXTH'						=> 'шестая',
'L_SEVENTH'						=> 'седьмая',
'L_EIGTH'						=> 'восьмая',
'L_NINTH'						=> 'девятая',
'L_TENTH'						=> 'десятая',
'L_NTH'							=> 'и',
'L_CAPCHA_QUESTION'				=> 'Напечатйте, какая <span class="capcha-letter">%s</span> буква в этом тексте <span class="capcha-word">%s</span>?',

# class.plx.utils.php
'L_WRITE_ACCESS'				=> '%s имеет доступ на запись',
'L_WRITE_NOT_ACCESS'			=> '%s не имеет доступ на запись или не существует',
'L_MODREWRITE_AVAILABLE'		=> 'Apache URL модуля mod_rewrite доступны',
'L_MODREWRITE_NOT_AVAILABLE'	=> 'Apache URL модуля mod_rewrite недоступен',
'L_LIBGD_INSTALLED'				=> 'GD библиотека установлена',
'L_LIBGD_NOT_INSTALLED'			=> 'GD библиотека не установлена',
'L_MAIL_AVAILABLE'				=> 'функция отправки почты доступна',
'L_MAIL_NOT_AVAILABLE'			=> 'Функция отправки почты недоступна',

# class.plx.motor.php
'L_FILE_VERSION_REQUIRED'		=> 'Файл "%sversion" требуется для PluXml',
'L_ARTICLE_NO_TAG'				=> 'Для этого тега нет статьи!',
'L_UNKNOWN_CATEGORY'			=> 'Эта категория не существует!',
'L_NO_ARTICLE_PAGE'				=> 'Нет статей в этой категории!',
'L_UNKNOWN_ARTICLE'				=> 'Эта статья не существует!',
'L_COM_IN_MODERATION'			=> 'Спасибо! Ваш комментарий появится после проверки',
'L_UNKNOWN_STATIC'				=> 'Эта страница не существует!',
'L_DOCUMENT_NOT_FOUND'			=> 'Документ не найден',
'L_NEWCOMMENT_ERR'				=> 'Произошла ошибка при публикации комментария',
'L_NEWCOMMENT_FIELDS_REQUIRED'	=> 'Пожалуйста, заполните все необходимые поля',
'L_NEWCOMMENT_ERR_ANTISPAM'		=> 'Ошибка проверки Антиспам',

# class.plx.show.php

'L_HTTPENCODING'				=> 'Сжатие %s активированно',
'L_PAGETITLE_ARCHIVES'			=> 'Архив',
'L_PAGETITLE_TAG'				=> 'Тэги',
'L_NO_CATEGORY'					=> 'без категории',
'L_CATEGORY'					=> 'категория',
'L_CATEGORIES'					=> 'категории',
'L_NO_ARTICLE'					=> 'нет статьи',
'L_ARTICLE'						=> 'статья',
'L_ARTICLES'					=> 'статей',
'L_ARTAUTHOR_UNKNOWN'			=> 'неизвестный',
'L_ARTTAGS_NONE'				=> 'нет',
'L_ARTCHAPO'					=> 'Читать далее',
'L_ARTFEED_RSS_CATEGORY'		=> 'RSS-поток категорий',
'L_ARTFEED_RSS_TAG'				=> 'RSS-поток статей в этом теге',
'L_ARTFEED_RSS'					=> 'RSS-поток статей',
'L_NO_COMMENT'					=> 'нет комментариев',
'L_COMMENT'						=> 'комментарий',
'L_COMMENTS'					=> 'комментария',
'L_COMFEED_RSS_ARTICLE'			=> 'RSS-поток комментариев статей',
'L_COMFEED_RSS'					=> 'RSS-поток комментариев',
'L_STATICCONTENT_INPROCESS'		=> 'Эта страница в настоящее время редактируется',
'L_SAID'						=> 'сказал',

'L_PAGINATION_FIRST_TITLE'		=> 'Перейти на первую страницу',
'L_PAGINATION_FIRST'			=> '&laquo;',
'L_PAGINATION_PREVIOUS_TITLE'	=> 'Предыдущая страница',
'L_PAGINATION_PREVIOUS'			=> 'Назад',
'L_PAGINATION_NEXT_TITLE'		=> 'Следующая страница',
'L_PAGINATION_NEXT'				=> 'Далее',
'L_PAGINATION_LAST_TITLE'		=> 'Перейти к последней странице',
'L_PAGINATION_LAST'				=> '&raquo;',
'L_PAGINATION'					=> 'страниц %s из %s',

'L_PAGEBLOG_TITLE'				=> 'Блог',

# class.plx.feed.php
'L_FEED_NO_PRIVATE_URL'			=> 'Закрытые URL не был инициализированы в настройках Админпанели!',
'L_FEED_COMMENTS'				=> 'Комментарии',
'L_FEED_ONLINE_COMMENTS'		=> 'Комментарии онлайн',
'L_FEED_OFFLINE_COMMENTS'		=> 'Комментарии оффлайн',
'L_FEED_WRITTEN_BY'				=> 'Автор',

);
?>

==> pluxml_5.5.orig.tar.gz: PluXml-5.5/core/lang/ru/core.php <==
<?php

$LANG = array(

'L_LANGUE'						=> 'Russian',

'L_DATE_CREATION'				=> 'Дата создания',
'L_DATE_UPDATE'					=> 'Дата обновляются',

# common
'L_PLUXML_VERSION'				=> 'PluXml версия',
'L_HOMEPAGE'					=> 'Главная',
'L_UNCLASSIFIED'				=> 'Без категории',
'L_INFO_PHP_VERSION'			=> 'PHP версия',
'L_INFO_MAGIC_QUOTES'			=> 'Состояние "magic quotes"',
'L_INFO_CHARSET'				=> 'кодировка',

# index.php
'L_ERR_THEME_NOTFOUND'			=> 'Тема не найдена',
'L_ERR_FILE_NOTFOUND'			=> 'Файл не найден',
'L_ERR_PAGE_NOT_FOUND'			=> 'Страница не найдена',

# class.plx.date.php
'L_SHORT_JANUARY'				=> '',
'L_SHORT_FEBRUARY'				=> '',
'L_SHORT_MARCH'					=> '',
'L_SHORT_APRIL'					=> '',
'L_SHORT_MAY'					=> '',
'L_SHORT_JUNE'					=> '',
'L_SHORT_JULY'					=> '',
'L_SHORT_AUGUST'				=> '',
'L_SHORT_SEPTEMBER'				=> '',
'L_SHORT_OCTOBER'				=> '',
'L_SHORT_NOVEMBER'				=> '',
'L_SHORT_DECEMBER'				=> '',
'L_JANUARY'						=> 'январь',
'L_FEBRUARY'					=> 'февраль',
'L_MARCH'						=> 'март',
'L_APRIL'						=> 'апрель',
'L_MAY'							=> 'май',
'L_JUNE'						=> 'июнь',
'L_JULY'						=> 'июль',
'L_AUGUST'						=> 'август',
'L_SEPTEMBER'					=> 'сентябрь',
'L_OCTOBER'						=> 'октябрь',
'L_NOVEMBER'					=> 'ноябрь',
'L_DECEMBER'					=> 'декабрь',
'L_MONDAY'						=> 'понедельник',
'L_TUESDAY'						=> 'вторник',
'L_WEDNESDAY'					=> 'среда',
'L_THURSDAY'					=> 'четверг',
'L_FRIDAY'						=> 'пятница',
'L_SATURDAY'					=> 'субота',
'L_SUNDAY'						=> 'воскресенье',

# class.plx.capcha.php
'L_LAST'						=> 'последняя',
'L_FIRST'						=> 'первая',
'L_SECOND'						=> 'вторая',
'L_THIRD'						=> 'третья',
'L_FOURTH'						=> 'четвертая',
'L_FIFTH'						=> 'пятая',
'L_SIXTH'						=> 'шестая',
'L_SEVENTH'						=> 'седьмая',
'L_EIGTH'						=> 'восьмая',
'L_NINTH'						=> 'девятая',
'L_TENTH'						=> 'десятая',
'L_NTH'							=> 'и',
'L_CAPCHA_QUESTION'				=> 'Напечатйте, какая <span class="capcha-letter">%s</span> буква в этом тексте <span class="capcha-word">%s</span>?',

# class.plx.utils.php
'L_WRITE_ACCESS'				=> '%s имеет доступ на запись',
'L_WRITE_NOT_ACCESS'			=> '%s не имеет доступ на запись или не существует',
'L_MODREWRITE_AVAILABLE'		=> 'Apache URL модуля mod_rewrite доступны',
'L_MODREWRITE_NOT_AVAILABLE'	=> 'Apache URL модуля mod_rewrite недоступен',
'L_LIBGD_INSTALLED'				=> 'GD библиотека установлена',
'L_LIBGD_NOT_INSTALLED'			=> 'GD библиотека не установлена',
'L_MAIL_AVAILABLE'				=> 'функция отправки почты доступна',
'L_MAIL_NOT_AVAILABLE'			=> 'Функция отправки почты недоступна',

# class.plx.motor.php
'L_ARTICLE_NO_TAG'				=> 'Для этого тега нет статьи!',
'L_UNKNOWN_CATEGORY'			=> 'Эта категория не существует!',
'L_NO_ARTICLE_PAGE'				=> 'Нет статей в этой категории!',
'L_UNKNOWN_ARTICLE'				=> 'Эта статья не существует!',
'L_COM_IN_MODERATION'			=> 'Спасибо! Ваш комментарий появится после проверки',
'L_UNKNOWN_STATIC'				=> 'Эта страница не существует!',
'L_DOCUMENT_NOT_FOUND'			=> 'Документ не найден',
'L_NEWCOMMENT_ERR'				=> 'Произошла ошибка при публикации комментария',
'L_NEWCOMMENT_FIELDS_REQUIRED'	=> 'Пожалуйста, заполните все необходимые поля',
'L_NEWCOMMENT_ERR_ANTISPAM'		=> 'Ошибка проверки Антиспам',

# class.plx.show.php

'L_HTTPENCODING'				=> 'Сжатие %s активированно',
'L_PAGETITLE_ARCHIVES'			=> 'Архив',
'L_PAGETITLE_TAG'				=> 'Тэги',
'L_NO_CATEGORY'					=> 'без категории',
'L_CATEGORY'					=> 'категория',
'L_CATEGORIES'					=> 'категории',
'L_NO_ARTICLE'					=> 'нет статьи',
'L_ARTICLE'						=> 'статья',
'L_ARTICLES'					=> 'статей',
'L_ARTAUTHOR_UNKNOWN'			=> 'неизвестный',
'L_ARTTAGS_NONE'				=> 'нет',
'L_ARTCHAPO'					=> 'Читать далее',
'L_ARTFEED_RSS_CATEGORY'		=> 'RSS-поток категорий',
'L_ARTFEED_RSS_TAG'				=> 'RSS-поток статей в этом теге',
'L_ARTFEED_RSS'					=> 'RSS-поток статей',
'L_NO_COMMENT'					=> 'нет комментариев',
'L_COMMENT'						=> 'комментарий',
'L_COMMENTS'					=> 'комментария',
'L_COMFEED_RSS_ARTICLE'			=> 'RSS-поток комментариев статей',
'L_COMFEED_RSS'					=> 'RSS-поток комментариев',
'L_STATICCONTENT_INPROCESS'		=> 'Эта страница в настоящее время редактируется',
'L_SAID'						=> 'сказал',

'L_PAGINATION_FIRST_TITLE'		=> 'Перейти на первую страницу',
'L_PAGINATION_FIRST'			=> '&laquo;',
'L_PAGINATION_PREVIOUS_TITLE'	=> 'Предыдущая страница',
'L_PAGINATION_PREVIOUS'			=> 'Назад',
'L_PAGINATION_NEXT_TITLE'		=> 'Следующая страница',
'L_PAGINATION_NEXT'				=> 'Далее',
'L_PAGINATION_LAST_TITLE'		=> 'Перейти к последней странице',
'L_PAGINATION_LAST'				=> '&raquo;',
'L_PAGINATION'					=> 'страниц %s из %s',

'L_PAGEBLOG_TITLE'				=> 'Блог',

# class.plx.feed.php
'L_FEED_NO_PRIVATE_URL'			=> 'Закрытые URL не был инициализированы в настройках Админпанели!',
'L_FEED_COMMENTS'				=> 'Комментарии',
'L_FEED_ONLINE_COMMENTS'		=> 'Комментарии онлайн',
'L_FEED_OFFLINE_COMMENTS'		=> 'Комментарии оффлайн',
'L_FEED_WRITTEN_BY'				=> 'Автор',

);
?>
